# the plugin code was generated by this script
# you should not change the plugin code directly, but this script
# note: this script only creates objects in your workspace,
# *EXCEPT* for the last call, see below.

require(rkwarddev)

local({
# set the output directory to overwrite the actual plugin
output.dir <- tempdir()
overwrite <- TRUE

about.info <- rk.XML.about(
	name="rk.ClusterAnalysis",
	author=c(
		person(given="Meik", family="Michalke",
			email="meik.michalke@hhu.de", role=c("aut","cre"))),
	about=list(desc="RKWard GUI to conduct k-means, model based and hierarchical cluster analyses",
		version="0.01-2", url="http://rkward.sf.net"),
	dependencies=list(rkward.min="0.5.6"),
	package=list(c(name="mclust"))
	)

############
## re-used objects
############

# for plots
generic.plot.options <- rk.XML.embed(component="rkward::plot_options", button=TRUE, label="Generic plot options")

# for data
var.select <- rk.XML.varselector(label="Select data")
var.data <- rk.XML.varslot(label="Data (matrix or data.frame)", source=var.select, classes=c("data.frame", "matrix"), required=TRUE)
selected.vars <- rk.XML.varslot(label="Selected variables", source=var.select, multi=TRUE)
frame.selected.vars <- rk.XML.frame(selected.vars, label="Use only a subset of variables", checkable=TRUE, chk=FALSE)

# prepare data
clust.pre.omitNA <- rk.XML.cbox("Remove missing values", value="true", chk=TRUE)
clust.pre.scale <- rk.XML.cbox("Stadardize values", value="true")
clust.pre.frame <- rk.XML.frame(
	rk.XML.row(
		rk.XML.col(clust.pre.omitNA),
		rk.XML.col(clust.pre.scale)
	),
	label="Data preparation")

# for logic sections
lgc.df.script <- rk.comment(id("
	gui.addChangeCommand(\"", var.data, ".available\", \"dataChanged()\");
	// this function is called whenever the data was changed
	dataChanged = function(){
			var thisObject = makeRObject(gui.getValue(\"", var.data, ".available\"));
			if(!thisObject.isDataFrame()){
				gui.setValue(\"", frame.selected.vars, ".enabled\", \"false\");
			} else {}
		}", js=FALSE))

lgc.current.object <- rk.XML.connect(governor="current_object", client=var.data, set="available")
lgc.data.from.selection <- rk.XML.connect(governor=var.data, client=var.select, get="available", set="root")
gov.data <- rk.XML.convert(sources=list(available=var.data), mode=c(notequals=""))
lgc.enable.selected <- rk.XML.connect(governor=gov.data, client=frame.selected.vars, set="enabled")

# for JavaScript
js.frm.subset <- rk.JS.vars(frame.selected.vars, modifiers="checked") # see if the frame is checked
js.selected.vars <- rk.JS.vars(selected.vars, modifiers="shortname", join="\\\", \\\"") # get selected vars
js.data.preparation <- rk.paste.JS(
	js.frm.subset,
	js.selected.vars,
	ite(id(js.frm.subset, " & ", js.selected.vars, " != \"\""), echo("\t# Use subset of variables\n\t",
		var.data, " <- subset(",var.data,", select=c(\"", js.selected.vars, "\"))\n")),
	ite(clust.pre.omitNA, echo("\t# Listwise removal of missings\n\t",
		var.data, " <- na.omit(", var.data, ")\n")),
	ite(clust.pre.scale, echo("\t# Standardizing values\n\t",
		var.data, " <- scale(", var.data, ")\n")))
# print selected subsets, if needed
js.prt.subset <- ite(id(js.frm.subset, " & ", js.selected.vars, " != \"\""),
	echo("\nrk.header(\"Subset of variables included the analysis\", level=3)\nrk.print(list(\"", js.selected.vars, "\"))\n\n"))

############
## k-means
############
clust.k.spin.numcl <- rk.XML.spinbox(label="Number of clusters to extract", min=2, real=FALSE)

clust.k.drop.meth <- rk.XML.dropdown(label="Algorithm", options=list(
		"Hartigan & Wong"=c(val="Hartigan-Wong", chk=TRUE),
		"Lloyd"=c(val="Lloyd"),
		"Forgy"=c(val="Forgy"),
		"MacQueen"=c(val="MacQueen")
	))

clust.k.spin.maxiter <- rk.XML.spinbox(label="Maximum number of iterations", min=1, initial=10, real=FALSE)
clust.k.spin.nstart <- rk.XML.spinbox(label="Initial random set of centers", min=1, initial=1, real=FALSE)

save.results.k <- rk.XML.saveobj("Save results to workspace", initial="clust.k.result")

# plot results
clust.plotk.cbox.dend <- rk.XML.cbox("Plot results", val="true", chk=TRUE)
clust.plotk.chk.points <- rk.XML.cbox("Plot cluster centers", val="true", chk=TRUE)

clust.plotk.preview <- rk.XML.preview()

tab.k.data <- rk.XML.row(
		var.select,
		rk.XML.col(
			var.data,
			frame.selected.vars,
			clust.pre.frame,
			rk.XML.frame(clust.k.spin.numcl),
			rk.XML.stretch(),
			rk.XML.frame(
				clust.k.drop.meth,
				rk.XML.row(
					rk.XML.col(clust.k.spin.maxiter),
					rk.XML.col(clust.k.spin.nstart)
				),
				clust.plotk.cbox.dend,
				label="Advanced options"),
			save.results.k
		)
	)

tab.k.plot <- rk.XML.row(
		rk.XML.col(
			clust.plotk.chk.points,
			rk.XML.stretch(),
			generic.plot.options,
			clust.plotk.preview)
	)

clust.k.full.dialog <- rk.XML.dialog(
	rk.XML.tabbook(tabs=list(
		"Data"=tab.k.data,
		"Plot"=tab.k.plot
	)),
	label="Cluster analysis: K-means partitioning")

lgc.sect.k <- rk.XML.logic(
		lgc.current.object,
		lgc.data.from.selection,
		gov.data,
		lgc.enable.selected,
		lgc.df.script,
		rk.XML.connect(governor=clust.plotk.cbox.dend, client=tab.k.plot, set="enabled")
	)

## JavaScript
clust.k.js.calc <- rk.paste.JS(
	js.data.preparation,
	echo("\tclust.k.result <- kmeans("),
	ite(var.data, echo("\n\t\tx=", var.data)),
	echo(",\n\t\tcenters=", clust.k.spin.numcl),
	ite(id(clust.k.drop.meth, " != \"Hartigan-Wong\""), echo(",\n\t\talgorithm=\"", clust.k.drop.meth,"\"")),
	ite(id(clust.k.spin.maxiter, " != 10"), echo(",\n\t\titer.max=", clust.k.spin.maxiter)),
	ite(id(clust.k.spin.nstart, " != 1"), echo(",\n\t\tnstart=", clust.k.spin.nstart)),
	echo("\n\t)\n\n")
)

clust.k.js.plot <- rk.paste.JS(
	js.frm.subset,
	js.selected.vars,
	ite(clust.plotk.cbox.dend, rk.paste.JS(
		rk.comment("in case there are generic plot options defined:"),
		js.po.printout <- rk.JS.vars(generic.plot.options, modifiers="code.printout", check.modifiers=FALSE),
		ite("full", echo("rk.graph.on()\n")),
		echo("\ttry({\n\t\tplot(", var.data,",\n\t\t\tcol=clust.k.result$cluster"),
		ite(id("!", js.po.printout, ".match(/main\\s*=/)"),
			echo(",\n\t\t\tmain=\"K-means partitioning\"")),
		ite(id("!", js.po.printout, ".match(/sub\\s*=/)"),
			echo(",\n\t\t\tsub=\"Grouped into ", clust.k.spin.numcl, " clusters by the ", clust.k.drop.meth, " algorithm\"")),
		# generic plot options go here
		echo(js.po.printout, ")"),
		ite(clust.plotk.chk.points,
			echo("\n\t\tpoints(clust.k.result$centers, col=1:", clust.k.spin.numcl, ", pch=8, cex=2)")),
		echo("\n\t})\n"),
		ite("full", echo("rk.graph.off()\n")), level=1)),
	ite("full", rk.paste.JS(echo("\nrk.print(clust.k.result)\n"), js.prt.subset))
)

############
## hierarchical
############
clust.h.drop.dist <- rk.XML.dropdown(label="Computation method", options=list(
		"Euclidean"=c(val="euclidean", chk=TRUE),
		"Maximum"=c(val="maximum"),
		"Manhattan (city block)"=c(val="manhattan"),
		"Canberra"=c(val="canberra"),
		"Binary"=c(val="binary"),
		"Minkowski"=c(val="minkowski")
	))
clust.h.drop.clst <- rk.XML.dropdown(label="Agglomeration method", options=list(
		"Ward"=c(val="ward", chk=TRUE),
		"Single linkage (nearest neighbor)"=c(val="single"),
		"Complete linkage (furthest neighbor)"=c(val="complete"),
		"Average linkage (between groups linkage)"=c(val="average"),
		"McQuitty"=c(val="mcquitty"),
		"Median clustering"=c(val="median"),
		"Centroid clustering"=c(val="centroid")
	))
clust.h.spin.pwmink <- rk.XML.spinbox(label="Power of Minkowski distance", min=1, initial=2, real=FALSE)

save.results.h <- rk.XML.saveobj("Save results to workspace", initial="clust.h.result")

# dendrogram
clust.dend.cbox.dend <- rk.XML.cbox("Draw dendrogram", val="true", chk=TRUE)
clust.dend.spin.numcl <- rk.XML.spinbox(label="Draw border around clusters (1 for none)", min=1, initial=1, real=FALSE)

clust.dend.cbox.unit <- rk.XML.cbox("Plot splits at equally-spaced heights (not at height in object)", val="true", chk=FALSE)
clust.dend.spin.hang <- rk.XML.spinbox(label="Fraction of height by which labels should hang below plot", min=0, initial=0.1, real=TRUE)
clust.dend.spin.hmin <- rk.XML.spinbox(label="Minimum height (suppress details below)", min=0, initial=0, real=TRUE)

clust.dend.preview <- rk.XML.preview()

tab.data <- rk.XML.row(
		var.select,
		rk.XML.col(
			var.data,
			frame.selected.vars,
			clust.pre.frame,
			rk.XML.stretch(),
			rk.XML.frame(clust.h.drop.dist, clust.h.spin.pwmink, label="Distance matrix"),
			rk.XML.frame(clust.h.drop.clst, label="Clustering"),
			clust.dend.cbox.dend,
			save.results.h
		)
	)

tab.dendrogram <- rk.XML.row(
		rk.XML.col(
			clust.dend.spin.numcl,
			clust.dend.spin.hang,
			clust.dend.spin.hmin,
			rk.XML.frame(clust.dend.cbox.unit),
			rk.XML.stretch(),
			generic.plot.options,
			clust.dend.preview)
	)

clust.h.full.dialog <- rk.XML.dialog(
	rk.XML.tabbook(tabs=list(
		"Data"=tab.data,	
		"Dendrogram"=tab.dendrogram
	)),
	label="Cluster analysis: Hierarchical")

## logic section
	lgc.sect.h <- rk.XML.logic(
		lgc.current.object,
		lgc.data.from.selection,
		gov.data,
		lgc.enable.selected,
		lgc.df.script,
		CA.gov.dist <- rk.XML.convert(sources=list(string=clust.h.drop.dist), mode=c(equals="minkowski")),
		rk.XML.connect(governor=CA.gov.dist, client=clust.h.spin.pwmink, set="enabled"),
		rk.XML.connect(governor=clust.dend.cbox.dend, client=tab.dendrogram, set="enabled"),
		rk.XML.set(generic.plot.options, set="allow_type", to=FALSE),
		rk.XML.set(generic.plot.options, set="axistypes.visible", to=FALSE),
		rk.XML.set(generic.plot.options, set="scale.visible", to=FALSE)
	)

## JavaScript
clust.h.js.calc <- rk.paste.JS(
#	js.selected.vars,
	js.data.preparation,
	echo("\t# Compute distance matrix\n\tclust.h.distances <- dist("),
	ite(var.data, echo("\n\t\tx=", var.data)),
	echo(",\n\t\tmethod=\"", clust.h.drop.dist, "\""),
	ite(id(clust.h.drop.dist, " == \"minkowski\""), echo(",\n\t\tp=", clust.h.spin.pwmink)),
	echo("\n\t)\n"),
	echo("\t# Hierarchical CA\n\tclust.h.result <- hclust(d=clust.h.distances"),
	echo(",\n\t\tmethod=\"", clust.h.drop.clst, "\""),
	echo("\n\t)\n\n")
)

clust.h.js.dend <- rk.paste.JS(
	js.frm.subset,
	js.selected.vars,
	ite(clust.dend.cbox.dend, rk.paste.JS(
		rk.comment("in case there are generic plot options defined:"),
		js.po.printout <- rk.JS.vars(generic.plot.options, modifiers="code.printout", check.modifiers=FALSE),
		ite("full", echo("rk.graph.on()\n")),
		echo("\ttry({\n\t\tplclust(clust.h.result"),
		ite(id("!", js.po.printout, ".match(/main\\s*=/)"),
			echo(",\n\t\t\tmain=\"Cluster dendrogram\"")),
		ite(id("!", js.po.printout, ".match(/sub\\s*=/)"),
			echo(",\n\t\t\tsub=\"Distance computation: ", clust.h.drop.dist, ", agglomeration method: ",clust.h.drop.clst,"\"")),
		ite(id("!", js.po.printout, ".match(/xlab\\s*=/)"),
			echo(",\n\t\t\txlab=\"Data: ", var.data, "\"")),
		ite(clust.dend.cbox.unit, echo(",\n\t\t\tunit=TRUE")),
		ite(id(clust.dend.spin.hang, " != 0.1"), echo(",\n\t\t\thang=", clust.dend.spin.hang)),
		ite(id(clust.dend.spin.hmin, " != 0"), echo(",\n\t\t\thmin=", clust.dend.spin.hmin)),
		# generic plot options go here
		echo(js.po.printout, ")"),
		ite(id(clust.dend.spin.numcl, " > 1"),
			echo("\n\t\trect.hclust(clust.h.result, k=", clust.dend.spin.numcl, ", border=\"red\")")),
		echo("\n\t})\n"),
		ite("full", echo("rk.graph.off()\n")), level=1)),
	ite("full", rk.paste.JS(echo("\nrk.print(clust.h.result)\n"), js.prt.subset))
)

## make a whole component
clust.h.component <- rk.plugin.component("Hierarchical CA",
	xml=list(
		dialog=clust.h.full.dialog,
		logic=lgc.sect.h),
	js=list(
#		require="fcp",
		calculate=clust.h.js.calc,
		doPrintout=clust.h.js.dend
	),
	hierarchy=list("analysis", "Cluster analysis"),
	create=c("xml", "js"))

#############
## model based CA
#############
clust.m.spin.numcl <- rk.XML.spinbox(label="Max number of clusters to test", min=2, initial=9, real=FALSE)

save.results.m <- rk.XML.saveobj("Save results to workspace", initial="clust.m.result")

# dendrogram
clust.plotm.cbox.plot <- rk.XML.cbox("Plot results", val="true", chk=TRUE)
clust.plotm.type <- rk.XML.radio("Plot type", options=list(
		"BIC"=c(val="BIC", chk=TRUE),
		"Classification"=c(val="classification"),
		"Classification uncertainty"=c(val="uncertainty"),
		"Density"=c(val="density")
	))

clust.plotm.preview <- rk.XML.preview()

tab.m.data <- rk.XML.row(
		var.select,
		rk.XML.col(
			var.data,
			frame.selected.vars,
			clust.pre.frame,
			rk.XML.stretch(),
			rk.XML.frame(
				clust.m.spin.numcl,
				clust.plotm.cbox.plot,
				label="Advanced options"),
			save.results.m
		)
	)

tab.m.plot <- rk.XML.row(
		rk.XML.col(
			clust.plotm.type,
			rk.XML.stretch(),
#			generic.plot.options,
			clust.plotm.preview)
	)

clust.m.full.dialog <- rk.XML.dialog(
	rk.XML.tabbook(tabs=list(
		"Data"=tab.m.data,	
		"Plot"=tab.m.plot
	)),
	label="Cluster analysis: Model based")

## logic section
	lgc.sect.m <- rk.XML.logic(
		lgc.current.object,
		lgc.data.from.selection,
		gov.data,
		lgc.enable.selected,
		lgc.df.script,
		rk.XML.connect(governor=clust.plotm.cbox.plot, client=tab.m.plot, set="enabled")
	)

## JavaScript
clust.m.js.calc <- rk.paste.JS(
	js.data.preparation,
	echo("\t# Model based CA\n\tclust.m.result <- Mclust(data=", var.data),
	ite(id(clust.m.spin.numcl, " != 9"), echo(",\n\t\tG=1:", clust.m.spin.numcl, "\n\t")),
	echo(")\n\n")
)

clust.m.js.plot <- rk.paste.JS(
	js.frm.subset,
	js.selected.vars,
	ite(clust.plotm.cbox.plot, rk.paste.JS(
# 		rk.comment("in case there are generic plot options defined:"),
# 		js.po.printout <- rk.JS.vars(generic.plot.options, modifiers="code.printout", check.modifiers=FALSE),
		ite("full", echo("rk.graph.on()\n")),
		echo("\ttry({\n\t\tplot(clust.m.result,\n\t\t\tdata=",var.data,
		",\n\t\t\twhat=\"", clust.plotm.type, "\""),
# 		# generic plot options go here
# 		echo(js.po.printout),
		echo(")\n\t})\n"),
		ite("full", echo("rk.graph.off()\n")), level=1)),
	ite("full", rk.paste.JS(echo("\nrk.print(clust.m.result)\n"), js.prt.subset))
)

## make a whole component
clust.m.component <- rk.plugin.component("Model based CA",
	xml=list(
		dialog=clust.m.full.dialog,
		logic=lgc.sect.m),
	js=list(
		require="mclust",
		calculate=clust.m.js.calc,
		doPrintout=clust.m.js.plot
	),
	hierarchy=list("analysis", "Cluster analysis"),
	create=c("xml", "js"))


#############
## number of clusters
#############
clust.num.radio.type <- rk.XML.radio("Method", options=list(
		"K-means total within sum of sqares"=c(val="kmeans"),
		"Hiearchical clustering criterion (Inverse Scree)"=c(val="hclust", chk=TRUE)
	))

clust.num.spin.numcl <- rk.XML.spinbox(label="Maximum number of clusters to exexamine", min=2, initial=15, real=FALSE)

clust.num.preview <- rk.XML.preview()

clust.num.full.dialog <- rk.XML.dialog(
	rk.XML.row(
		var.select,
		rk.XML.col(
			var.data,
			frame.selected.vars,
			clust.pre.frame,
			rk.XML.stretch(),
			rk.XML.frame(clust.num.radio.type, clust.num.spin.numcl),
			clust.num.frm.dist <- rk.XML.frame(clust.h.drop.dist, clust.h.spin.pwmink, label="Distance matrix"),
			clust.num.frm.clst <- rk.XML.frame(clust.h.drop.clst, label="Clustering"),
			generic.plot.options,
			clust.num.preview)
	)
, label="Cluster analysis: Determine number of clusters")

## logic section
	lgc.sect.num <- rk.XML.logic(
		lgc.current.object,
		lgc.data.from.selection,
		gov.data,
		lgc.enable.selected,
		lgc.df.script,
		CA.gov.dist.num <- rk.XML.convert(sources=list(string=clust.h.drop.dist), mode=c(equals="minkowski")),
		rk.XML.connect(governor=CA.gov.dist.num, client=clust.h.spin.pwmink, set="enabled"),
		CA.gov.dist.num.type <- rk.XML.convert(sources=list(string=clust.num.radio.type), mode=c(equals="hclust")),
		rk.XML.connect(governor=CA.gov.dist.num.type, client=clust.num.frm.dist, set="enabled"),
		rk.XML.connect(governor=CA.gov.dist.num.type, client=clust.num.frm.clst, set="enabled")
	)


## JavaScript
# plot of within groups sum of squares x number of clusters
# see http://www.statmethods.net/advstats/cluster.html
clust.num.js.calc <- rk.paste.JS(
	js.data.preparation,
	ite(id(clust.num.radio.type, " == \"kmeans\" && ", var.data), echo("\t# Calculate within groups sum of squares",
		"\n\tclust.wss <- (nrow(",var.data,")-1) * sum(apply(",var.data,", 2, var))\n",
		"\tfor (i in 2:",clust.num.spin.numcl,"){\n\t\tclust.wss[i] <- kmeans(",var.data,", centers=i)$tot.withinss\n\t}\n\n")),
	ite(id(clust.num.radio.type, " == \"hclust\" && ", var.data), echo("\t# Get clustering criterion",
		"\n\tclust.from <- nrow(",var.data,")-",clust.num.spin.numcl,
		"\n\tclust.to <- nrow(",var.data,")-1",
		"\n\tclust.wss <- hclust(dist(",var.data,", method=\"", clust.h.drop.dist, "\"), method=\"",clust.h.drop.clst,"\")$height[clust.from:clust.to]\n\n"))
)

clust.num.js.print <- rk.paste.JS(
	js.frm.subset,
	js.selected.vars,
	rk.comment("in case there are generic plot options defined:"),
	js.po.printout <- rk.JS.vars(generic.plot.options, modifiers="code.printout", check.modifiers=FALSE),
	ite("full", echo("rk.graph.on()\n")),
	echo("\ttry({\n\t\tplot(\n\t\t\t"),
	ite(id(clust.num.radio.type, " == \"kmeans\""),
		rk.paste.JS(echo("1:",clust.num.spin.numcl,",\n\t\t\tclust.wss"),
		ite(id("!", js.po.printout, ".match(/type\\s*=/)"),
			echo(",\n\t\t\ttype=\"b\"")),
		ite(id("!", js.po.printout, ".match(/xlab\\s*=/)"),
			echo(",\n\t\t\txlab=\"Number of Clusters\"")),
		ite(id("!", js.po.printout, ".match(/ylab\\s*=/)"),
			echo(",\n\t\t\tylab=\"Within groups sum of squares\"")),
		ite(id("!", js.po.printout, ".match(/main\\s*=/)"),
			echo(",\n\t\t\tmain=\"Within sum of squares by clusters\"")),
		ite(id("!", js.po.printout, ".match(/sub\\s*=/)"),
			echo(",\n\t\t\tsub=\"Examined ", clust.num.spin.numcl, " clusters using k-means partitioning\"")),
		# generic plot options go here
		echo(js.po.printout, ")"), level=3)),
	ite(id(clust.num.radio.type, " == \"hclust\""),
		rk.paste.JS(echo("clust.wss"),
		ite(id("!", js.po.printout, ".match(/type\\s*=/)"),
			echo(",\n\t\t\ttype=\"b\"")),
		ite(id("!", js.po.printout, ".match(/xlab\\s*=/)"),
			echo(",\n\t\t\txlab=\"Number of Clusters\"")),
		ite(id("!", js.po.printout, ".match(/ylab\\s*=/)"),
			echo(",\n\t\t\tylab=\"Agglomeration criterion\"")),
		ite(id("!", js.po.printout, ".match(/main\\s*=/)"),
			echo(",\n\t\t\tmain=\"Inverse Scree plot\"")),
		ite(id("!", js.po.printout, ".match(/sub\\s*=/)"),
			echo(",\n\t\t\tsub=\"Examined ", clust.num.spin.numcl, " clusters (dist: ", clust.h.drop.dist, ", hclust: ",clust.h.drop.clst,")\"")),
		echo(",\n\t\t\txaxt=\"n\"",
		# generic plot options go here
		js.po.printout, ")\n\t\t",
		"axis(1, at=1:",clust.num.spin.numcl,", labels=",clust.num.spin.numcl, ":1)"), level=3)),
	echo("\n\t})\n"),
	ite("full", rk.paste.JS(echo("rk.graph.off()\n"), js.prt.subset))
)

## make a whole component
clust.num.component <- rk.plugin.component("Determine number of clusters",
	xml=list(
		dialog=clust.num.full.dialog,
		logic=lgc.sect.num),
	js=list(
#		require="fcp",
		calculate=clust.num.js.calc,
		doPrintout=clust.num.js.print),
	hierarchy=list("plots", "Cluster analysis"),
	create=c("xml", "js"))


#############
## if you run the following function call, files will be written to tempdir!
#############
# this is where it get's serious, that is, here all of the above is put together into one plugin

cluster.plugin.dir <<- rk.plugin.skeleton(
	about.info,
	path=output.dir,
	xml=list(
		dialog=clust.k.full.dialog,
		logic=lgc.sect.k),
	js=list(results.header="Cluster analysis",
#		require="fpc",
		calculate=clust.k.js.calc,
		doPrintout=clust.k.js.plot),
	pluginmap=list(name="K-means partitioning", hierarchy=list("analysis", "Cluster analysis")),
	components=list(
		clust.h.component,
		clust.m.component,
		clust.num.component),
	create=c("pmap", "xml", "js", "desc"),
	overwrite=overwrite,
	tests=FALSE,
#	edit=TRUE,
	load=TRUE)#,
#	show=TRUE)
})